@@ -44,7 +44,7 @@ See the README file for an example usage of this module.
 """
 
 
-__version__ = "$Id: cloghandler.py 5651 2008-09-09 21:58:14Z lowell $"
+__version__ = "$Id: cloghandler.py 5654 2008-09-10 22:09:56Z lowell $"
 __author__ = "Lowell Alleman"
 __all__ = [
     "ConcurrentRotatingFileHandler",
@@ -152,7 +152,12 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
                 warn("The given 'filename' should be an absolute path.  If your "
                      "application calls os.chdir(), your logs may get messed up. "
                      "Use 'supress_abs_warn=True' to hide this message.")
-        BaseRotatingHandler.__init__(self, filename, mode, encoding)
+        try:
+            BaseRotatingHandler.__init__(self, filename, mode, encoding)
+        except TypeError: # Due to a different logging release without encoding support  (Python 2.4.1 and earlier?)
+            BaseRotatingHandler.__init__(self, filename, mode)
+            self.encoding = encoding
+        
         self._rotateFailed = False
         self.maxBytes = maxBytes
         self.backupCount = backupCount
